//|*********************************************************************
//| File Name:       MessageConsole.mqh
//| File Type:       Include
//| Descritpion:     Function declarations for chart message console
//| Version:         beta
//| Date Created:    2009-02-04
//| Author:          Richard Holloway
//| Distribution:    Source
#property copyright  "Copyright  2009, Temple Street International"
#property link       "http://www.TempleStreet.CC"
//|*********************************************************************
//| MessageConsole may be freely distributed and used as long as none
//|           of the files are edited or altered in any way
//|*********************************************************************
#import              "MessageConsole.ex4"

//       PLEASE READ THE ENTIRE FILE

//       Place this file in C:\\Program Files\[MT4]\experts\include
//       The function library (MessageConsole.ex4) must be placed
//       in C:\\Program Files\[MT4]\experts\libraries

//       Your Experts file ([EA].mq4) must contain the following line 
//       prior to any MessageConsole function calls:
//       #include <MessageConsole.mqh>

//       MessageConsole consists of three functions enabling the user to
//       to post scrolling, color-coded messages in the bottom-left 
//       corner of any chart.  The user can control the number of text
//       lines, the size of the text, and the font.

int      StartMessageConsole(int TextLines, int FontSize, string FontName);
//       This function is used to start the MessageConsole, and is most
//       often placed within the init() function.  If the MessageConsole
//       is successfully started, the function returns the Chart ID (CID)
//       number.  The CID is then used by the other two functions to 
//       identify the proper chart for posting a message or stopping the
//       MessageConsole.
//       StartMessageConsole() uses (3) parameters:
//       TextLines   = the number of lines of text in the scrolling 
//                     console (must be less than 64)
//       FontSize    = the size of the text font (i.e. 9)
//       FontName    = the name of the font (i.e. "Arial");

bool     StopMessageConsole(int CID);
//       This function is used to stop the MessageConsole, and is most
//       often placed within the deinit() function.  If the
//       MessageConsole is successfully stopped, the function returns
//       TRUE, otherwise it returns FALSE.
//       StopMessageConsole() uses (1) parameter:
//       CID         = the Chart ID number obtained using 
//                     StartMessageConsole() function

bool     Post(int CID, string Message, color Color);
//       This is the main function used for posting messages to the
//       MessageConsole.  If the message is successfully posted, the
//       function returns TRUE, otherwise it returns FALSE.
//       Post() uses (3) parameters:
//       CID         = the Chart ID number obtained using 
//                     StartMessageConsole() function
//       Message     = the string to post to MessageConsole
//       Color       = the text color for the message to be posted
//       All messages that are posted to the MessageConsole are also
//       sent to the experts log using the standard Print() function.

//       LIMITATIONS:
//       1. StartMessageConsole() must be called before 
//          StopMessageConsole().
//       2. Post() must be called after StartMessageConsole() and
//          before StopMessageConsole().
//       3. The Message string must be 63 characters or less.
//       4. The TextLines must be 63 lines or less.
//       5. MessageConsole may only be used on 100 or fewer charts
//          at the same time.

//       BEST PRACTICES:
//       StartMessageConsole() and StopMessageConsole() may be called
//       from anywhere in the EA, as long as it is done in accordance
//       with the limitations above.  Calling Post() without having
//       called StartMessageConsole() will result in an error.
//       The example below illustrates the best way to use these 
//       functions:

//       int CID;

//       int init() {
//          CID=StartMessageConsole(8,9,"Arial");
//          return(0);
//       }

//       int deinit() {
//          if (!StopMessageConsole(CID)) Alert("Unable to stop MessageConsole");
//          return(0);
//       }

//       int start() {
//          if (!Post(CID,"Some message string you want to post",Yellow)) Alert("MessageConsole was not started");
//          return(0);
//       }

//       For questions, comments, suggestions, or to report bugs, please contact richard@templestreet.cc

//       DISCLAIMER:
//       USE AT YOUR OWN RISK!  Temple Street International is not liable
//       for any damage or financial loss that you may incur as a
//       result of using this software.